@@ -2,7 +2,9 @@ use crate::prelude::*;
 use soloud_sys::soloud as ffi;
 
 /// Ay audio type
-#[derive(Debug, AudioExt)]
+#[derive(Debug)]
 pub struct Ay {
-    _inner: *mut ffi::Ay,
+    inner: *mut ffi::Ay,
 }
+
+crate::macros::audio::impl_audio_ext!(Ay);
