@@ -3,15 +3,18 @@ use soloud_sys::soloud as ffi;
 use std::path::Path;
 
 /// Wavstream audio type
-#[derive(Debug, AudioExt, LoadExt)]
+#[derive(Debug)]
 pub struct WavStream {
-    _inner: *mut ffi::WavStream,
+    inner: *mut ffi::WavStream,
 }
 
+crate::macros::load::impl_load_ext!(WavStream);
+crate::macros::audio::impl_audio_ext!(WavStream);
+
 impl WavStream {
     /// Get the length of the WavStream object
     pub fn length(&self) -> f64 {
-        unsafe { ffi::WavStream_getLength(self._inner) }
+        unsafe { ffi::WavStream_getLength(self.inner) }
     }
 
     /// Load a file to memory
@@ -20,6 +23,6 @@ impl WavStream {
             .to_str()
             .ok_or(SoloudError::Internal(SoloudErrorKind::FileLoadFailed))?;
         let path = std::ffi::CString::new(path)?;
-        ffi_call!(ffi::WavStream_loadToMem(self._inner, path.as_ptr()))
+        ffi_call!(ffi::WavStream_loadToMem(self.inner, path.as_ptr()))
     }
 }
